@@ -9,8 +9,9 @@ f = Figlet(font="slant")
 
 print(f.renderText("packagetracker"))
 
-import getemails
-import inputPackage
-import tracker
+import os.path
+import packagetrack.getemails
+import packagetrack.inputPackage
+import packagetrack.tracker
 
 # print("Thanks for using our basic package tracker!")
